# installing required packages

install.packages("aod")
install.packages("ggplot2")
install.packages("ggfortify")
install.packages("forcats")
install.packages("dplyr")
install.packages('ggthemes', dependencies = TRUE)
install.packages("survival")
install.packages("ranger")
install.packages("survminer")
install.packages("multcomp")
install.packages("mixlm")
install.packages("multcompView")
install.packages("ggpubr")
install.packages("backports")
install.packages("RVAideMemoire")

# adding packages to library
library(backports)
library(ggpubr)
library(ggthemes)
library(MASS)
library(forcats)
library(dplyr)
library(survival)
library(survminer)
library(ranger)
library(ggfortify)
library(multcomp)
library(mixlm)
library(multcompView)
library(RVAideMemoire)
require(aod)
require(ggplot2)
require(forcats)

#Clear Memory
rm(list=ls())

# loading pupation data set

pupationsurvivalcurve <- read.csv("Supplemental_Data_2-Pupation_Survival_Curve.csv")

#subset pupal data to remove all yeast diet

pupationsurvivalcurve_no100AY <- subset(pupationsurvivalcurve, pupationsurvivalcurve$Diet != "100AY:0RF")

# plot raw data with logistic regression models

PupaeLR_plot <- ggplot(data = pupationsurvivalcurve_no100AY, aes(x=Pupation, y=Ratio, color=Diet))+
  geom_jitter(size=1.2)+
  stat_smooth(method = "glm", method.args = list(family ="quasibinomial"(link=logit)), se=TRUE, alpha=0.25)+
  xlab("Time (days)")+
  ylab("Pupae Count")+
  xlim(1,6)+
  scale_y_continuous(limits = c(0,1)) +
  theme_minimal()+
  labs(color = "Diet") +
  theme(legend.position = "right", text=element_text(size = 20)) +
  scale_color_manual(values = c("#FF33FF", "#990099","#6600FF", "#FF5733"))

#scale_color_manual(values = c("#FF33FF", "#66CDAA", "#990099","#6600FF", "#FF5733"))

PupaeLR_plot+
  theme(legend.box = "horizontal", aspect.ratio = 1)

# Kaplan-Meier Plot

DietKm_Fit <- surv_fit(Surv(Pupation, Outocome) ~ Diet, data = pupationsurvivalcurve)
summary(DietKm_Fit, times = c(1,2,3,4,5,6))
surv_median(DietKm_Fit, combine = FALSE)
#autoplot(DietKm_Fit, conf.int = FALSE)

ggsurv <- ggsurvplot(fit = DietKm_Fit, 
           legend = "right",
           size=2,
           palette = c("#FF33FF", "#66CDAA", "#990099","#6600FF", "#FF5733"),
           fun = "pct",
           xlab = "Time(Days)",
           ylab = "% of Remaining Larvae over Time")

ggsurv$plot+
  theme(legend.box = "horizontal", aspect.ratio = 1)

# Log-Rank Analysis Between Strains
# compare median pupation times
# statistical comparison, p values, is in the shapes of the curves

survdiff(Surv(Pupation, Outocome) ~ Diet, data = pupationsurvivalcurve)
pairwise_survival_difference <- pairwise_survdiff(Surv(Pupation, Outocome) ~ Diet, data = pupationsurvivalcurve)
pairwise_survival_difference

# input nutrition stores raw data

Nutrition.Assay.Review <- read.csv("Supplemental_Data_3-Nutrition_Assay_Results.csv")

#Base R command to remove extra rows and columns
# We only have data in row 1-70, and column 1-9
# removed 25RFM21 b/c outlier

Nutrition.Assay.Results <- Nutrition.Assay.Review[1:99, 1:14]

# Subset the data into male and female datasets 

FemaleNutrition <- Nutrition.Assay.Results[Nutrition.Assay.Results$sex == "F",]
MaleNutrition <- Nutrition.Assay.Results[Nutrition.Assay.Results$sex == "M",]

#Test for normality
byf.shapiro(ugSugar~diet, data = FemaleNutrition)
byf.shapiro(ug.Glycogen~diet, data = FemaleNutrition)
byf.shapiro(ug.Lipid.~diet, data = FemaleNutrition)

byf.shapiro(ugSugar~diet, data = MaleNutrition)
byf.shapiro(ug.Glycogen~diet, data = MaleNutrition)
byf.shapiro(ug.Lipid.~diet, data = MaleNutrition)


# Kruskal-Wallis Test, diet for sugar (Female)

KW_Sugar_F <- kruskal.test(ugSugar ~ diet, data = FemaleNutrition)
KW_Sugar_F

Wilcox_test_Sugar_F <- pairwise.wilcox.test(FemaleNutrition$ugSugar, FemaleNutrition$diet, p.adjust.method = "BH")
Wilcox_test_Sugar_F

# Kruskal-Wallis Test, diet for sugar (Male)

KW_Sugar_M <- kruskal.test(ugSugar ~ diet, data = MaleNutrition)
KW_Sugar_M

Wilcox_test_Sugar_M <- pairwise.wilcox.test(MaleNutrition$ugSugar, MaleNutrition$diet, p.adjust.method = "BH")
Wilcox_test_Sugar_M

# Kruskal-Wallis Test, diet for glycogen (Female)

KW_Glycogen_F <- kruskal.test(ug.Glycogen ~ diet, data = FemaleNutrition)
KW_Glycogen_F

Wilcox_test_Glycogen_F <- pairwise.wilcox.test(FemaleNutrition$ug.Glycogen, FemaleNutrition$diet, p.adjust.method = "BH")
Wilcox_test_Glycogen_F

# Kruskal-Wallis Test, diet for glycogen (Male)

KW_Glycogen_M <- kruskal.test(ug.Glycogen ~ diet, data = MaleNutrition)
KW_Glycogen_M

Wilcox_test_Glycogen_M <- pairwise.wilcox.test(MaleNutrition$ug.Glycogen, MaleNutrition$diet, p.adjust.method = "BH")
Wilcox_test_Glycogen_M


# Kruskal-Wallis Test, diet for lipid (Female)

KW_Lipid_F <- kruskal.test(ug.Lipid. ~ diet, data = FemaleNutrition)
KW_Lipid_F

Wilcox_test_Lipid_F <- pairwise.wilcox.test(FemaleNutrition$ug.Lipid., FemaleNutrition$diet, p.adjust.method = "BH")
Wilcox_test_Lipid_F

# Kruskal-Wallis Test, diet for lipid (Male)

KW_Lipid_M <- kruskal.test(ug.Lipid. ~ diet, data = MaleNutrition)
KW_Lipid_M

Wilcox_test_Lipid_F <- pairwise.wilcox.test(MaleNutrition$ug.Lipid., MaleNutrition$diet, p.adjust.method = "BH")
Wilcox_test_Lipid_F


# boxplots for nutrition stores
# sugar stores boxplot
ggplot(Nutrition.Assay.Results, aes(x=sex, y=Nutrition.Assay.Results$ugSugar, fill = diet))+
  geom_boxplot()+
  scale_x_discrete(breaks=c("F","M"), labels=c("Female", "Male")) +
  #theme_classic(base_family = "Avenir")+ 
  ylab("ug Sugar per mg")+
  theme(legend.position = "right", axis.title.x=element_blank(), text=element_text(size = 20)) +
  scale_fill_manual(values = c("#FF33FF", "#990099", "#6600FF", "#FF5733"))+
  theme(legend.box = "horizontal", aspect.ratio = 1)

# glycogen stores boxplot
ggplot(Nutrition.Assay.Results, aes(x=sex, y=Nutrition.Assay.Results$ug.Glycogen , fill = diet))+
  geom_boxplot()+
  scale_x_discrete(breaks=c("F","M"), labels=c("Female", "Male")) +
  #theme_classic(base_family = "Avenir")+
  ylab("ug Glycogen per mg")+
  theme(legend.position = "right", axis.title.x=element_blank(), text=element_text(size = 20)) +
  scale_fill_manual(values = c("#FF33FF", "#990099", "#6600FF", "#FF5733"))+
  theme(legend.box = "horizontal", aspect.ratio = 1)

# lipid stores boxplot 
ggplot(Nutrition.Assay.Results, aes(x=sex, y=Nutrition.Assay.Results$ug.Lipid., fill = diet))+
  geom_boxplot()+
  scale_x_discrete(breaks=c("F","M"), labels=c("Female", "Male")) +
  #theme_classic(base_family = "Avenir")+
  ylab("ug Lipid per mg")+
  theme(legend.position = "right", axis.title.x=element_blank(), text=element_text(size = 20)) +
  scale_fill_manual(values = c("#FF33FF", "#990099", "#6600FF", "#FF5733"))+
  theme(legend.box = "horizontal", aspect.ratio = 1)

# load raw adult body size data
df <- read.csv("Supplemental_Data_1-Winglength_and_Body_Size_Measurements.csv")

# Base R command to remove extra rows and columns
# We only have data in row 91-450, and column 1-7
# we dont want to include diet 1 because they did not survive to adulthood

DT <- df[91:450, 1:8]

# subset adult body size data with regard to sex
DTFemale <- subset(DT, DT$Sex == "Female")
DTMale <- subset(DT, DT$Sex == "Male")

#Check for normality of winglength and weight by Shapiro-Wilks test
byf.shapiro(Rwing40x~Diet, data = DTFemale)
byf.shapiro(Rwing40x~Diet, data = DTMale)

byf.shapiro(milligrams~Diet, data = DTFemale)
byf.shapiro(milligrams~Diet, data = DTMale)

# Kruskal-Wallis Test, diet for Winglength (Female)
KW_Winglength_F <- kruskal.test(Rwing40x~Diet, data = DTFemale)
KW_Winglength_F

Wilcox_test_Winglength_F <- pairwise.wilcox.test(DTFemale$Rwing40x, DTFemale$Diet, p.adjust.method = "BH")
Wilcox_test_Winglength_F

# Kruskal-Wallis Test, diet for Winglength (Male)
KW_Winglength_M <- kruskal.test(Rwing40x~Diet, data = DTMale)
KW_Winglength_M

Wilcox_test_Winglength_M <- pairwise.wilcox.test(DTMale$Rwing40x, DTMale$Diet, p.adjust.method = "BH")
Wilcox_test_Winglength_M

# Kruskal-Wallis Test, diet for Weight (Female)
KW_Weight_F <- kruskal.test(milligrams~Diet, data = DTFemale)
KW_Weight_F

Wilcox_test_Weight_F <- pairwise.wilcox.test(DTFemale$milligrams, DTFemale$Diet, p.adjust.method = "BH")
Wilcox_test_Weight_F

# Kruskal-Wallis Test, diet for Weight (Male)
KW_Winglength_M <- kruskal.test(milligrams~Diet, data = DTMale)
KW_Winglength_M

Wilcox_test_Winglength_M <- pairwise.wilcox.test(DTMale$milligrams, DTMale$Diet, p.adjust.method = "BH")
Wilcox_test_Winglength_M

# boxplot for weight
ggplot(DT, aes(x=Sex, y=DT$milligrams, fill = ..Diet))+
  geom_boxplot()+
  ylab("Weight (mg)")+
  theme(legend.position = "right", axis.title.x=element_blank(), text=element_text(size = 20)) +
  scale_fill_manual(values = c("#FF33FF", "#990099", "#6600FF", "#FF5733")) +
  theme_classic()+
  theme(legend.box = "horizontal", aspect.ratio = 1)
  #theme(axis.title.x=element_blank(),text = element_text(size = 20))

FGram_Sig_F
MGram_Sig_F

#boxplot for winglength
ggplot(DT, aes(x=Sex, y=DT$Lwing40x, fill = ..Diet))+
  geom_boxplot()+
  ylab("Wing Length (mm)")+
  theme(legend.position = "right", axis.title.x=element_blank(), text=element_text(size = 20)) +
  scale_fill_manual(values = c("#FF33FF", "#990099", "#6600FF", "#FF5733"))+
  theme_classic()+
  theme(legend.box = "horizontal", aspect.ratio = 1)
  #theme(axis.title.x=element_blank(), text = element_text(size = 20))

FWing_Sig_F
MWing_Sig_F